@@ -3,8 +3,9 @@
 import os
 import sys
 import argparse
+import json
 from sca2d import Analyser
-from sca2d.messages import print_messages, count_messages
+from sca2d.messages import print_messages, count_messages, gitlab_summary
 
 def parse_args():
     """
@@ -18,7 +19,7 @@ def parse_args():
                         type=str,
                         help="The .scad file to analyse or the directory to analyse.")
     parser.add_argument("--output-tree",
-                        help="Output the parse tree to output.sca2d",
+                        help="Output the parse tree to <filename>.sca2d",
                         action="store_true")
     parser.add_argument("--colour",
                         help=("Use colour when outputting the warning messages."
@@ -30,6 +31,9 @@ def parse_args():
     parser.add_argument("--debug",
                         help=("Also print SCA2D debug messages"),
                         action="store_true")
+    parser.add_argument("--gitlab-report",
+                        help=("Output a gitlab code quality report"),
+                        action="store_true")
     return parser.parse_args()
 
 
@@ -80,6 +84,10 @@ def main():
     message_summary = count_messages(all_messages)
     print(message_summary)
 
+    if args.gitlab_report:
+        with open("gl-code-quality-report.json", "w") as json_file:
+            json.dump(gitlab_summary(all_messages), json_file)
+
     if (message_summary.fatal + message_summary.error) > 0:
         sys.exit(1)
     sys.exit(0)
