@@ -45,7 +45,7 @@ def message_severity_gitlab(message):
     if code_type == "I":
         return "info"
     if code_type == "D":
-        return "info"
+        return "depreciated"
     #Skip other types
     return None
 
@@ -144,8 +144,7 @@ class Message:
         '''
         The line in the code where the a check raised this message.
         '''
-        if self.tree.line == 0:
-            return 1
+
         return self.tree.line
 
     @property
@@ -153,8 +152,7 @@ class Message:
         '''
         The column on Message.line of the code where the a check raised this message.
         '''
-        if self.tree.column == 0:
-            return 1
+
         return self.tree.column
 
     @property
@@ -202,6 +200,7 @@ MESSAGES = {
     "E0002": "Defining an non-keyword argument after a keyword argument.",
     "E0003": "Wrong number of input arguments for Built-In call: %s",
     "E0004": "Empty argument in function/module header.",
+    "E0005": "Empty item in list.",
     "E1001": "`use` or `include` can only be used in the outer scope.",
     "E2001": "Variable `%s` used but never defined.",
     "E2002": "Module `%s` used but never defined.",
@@ -211,6 +210,8 @@ MESSAGES = {
               " this is a bug in SCA2D please report it to us."),
     "E3002": "Cannot open file `%s`.\n[%s]",
     "E3003": "Cannot include %s as the include definitions form a loop.\n [%s]",
+    "W1001": "Used library `%s` is not needed.",
+    "W1002": "Included library `%s` is not needed.",
     "W2001": "Variable `%s` overwritten within scope.",
     "W2002": "Overwriting `%s` variable from a lower scope.",
     "W2003": "Module `%s` multiply defined within scope.",
@@ -225,9 +226,14 @@ MESSAGES = {
     "W2012": "Function %s is defined by multiple imports",
     "I0001": "Semicolon not required",
     "I0002": "Empty scope",
-    "I1003": "Debug modifier in use.",
+    "I0003": "Debug modifier in use.",
+    "I0004": "Module call scope is defined implcitly rather than with braces",
+    "I0005": "File contains %s global variables.",
+    "I0006": "Trailing whitespace.",
     "I1001": "Overly complicated argument contains %s tokens.",
+    "I1002": "Overly complicated expression contains %s tokens.",
     "I2001": "Assert called without message. Consider adding a message.",
+    "I3001": "Global: %s does not match upper case naming style.",
     "D0001": "Assign is depreciated. Use a regular assignment.",
     "U0001": "Token of type %s cannot be processed. This is a SCA2D problem",
     "U0002": "Token of type %s misidentified as complex expression. This is a SCA2D problem",
